pub enum ParamFlag {
Show 14 variants
Readable,
Writable,
ReadWrite,
Construct,
ConstructOnly,
LaxValidation,
StaticName,
Private,
StaticNick,
StaticBlurb,
StaticStrings,
ExplicitNotify,
Deprecated,
Unknown(String),
}Variants
Readable
The parameter is readable (value: 1)
Writable
The parameter is writable (value: 2)
ReadWrite
Alias for READABLE | WRITABLE (value: 3)
Construct
The parameter will be set upon object construction (value: 4)
ConstructOnly
The parameter can only be set upon object construction (value: 8)
LaxValidation
Strict validation not required upon parameter conversion (value: 16)
StaticName
String used as name is guaranteed to remain valid (value: 32)
Private
Internal flag (value: 32)
StaticNick
String used as nick is guaranteed to remain valid (value: 64)
StaticBlurb
String used as blurb is guaranteed to remain valid (value: 128)
StaticStrings
Alias for STATIC_NAME | STATIC_NICK | STATIC_BLURB
ExplicitNotify
No automatic notify signal emission (value: 1073741824)
Deprecated
The parameter is deprecated (value: 2147483648)
Unknown(String)
Custom or unrecognized flag
Implementations