ParamSpecAssignment

Enum ParamSpecAssignment 

pub enum ParamSpecAssignment {
    ArraySubscript {
        array_name: String,
        enum_value: String,
        statement_location: SourceLocation,
        call: CallExpression,
        property: Property,
        install_call: Option<CallExpression>,
    },
    Variable {
        variable_name: String,
        statement_location: SourceLocation,
        call: CallExpression,
        property: Property,
        install_call: Option<CallExpression>,
    },
    OverrideProperty {
        enum_value: String,
        statement_location: SourceLocation,
        call: CallExpression,
        property: Property,
    },
    DirectInstall {
        enum_value: String,
        statement_location: SourceLocation,
        call: CallExpression,
        property: Property,
        install_call: CallExpression,
    },
}
Information about a param_spec assignment found in a class_init function

Variants



ArraySubscript

Array subscript pattern: props[PROP_X] = g_param_spec_*()

Fields

array_name: String
enum_value: String
statement_location: SourceLocation
property: Property
install_call: Option<CallExpression>


Variable

Variable pattern: param_spec = g_param_spec_*()

Fields

variable_name: String
statement_location: SourceLocation
property: Property
install_call: Option<CallExpression>


OverrideProperty

Override property pattern: g_object_class_override_property(class, PROP_X, “name”)

Fields

enum_value: String
statement_location: SourceLocation
property: Property


DirectInstall

Direct install: g_object_class_install_property(class, PROP_X, g_param_spec_xxx(…))

Fields

enum_value: String
statement_location: SourceLocation
call: CallExpression

The inline g_param_spec_* call

property: Property
install_call: CallExpression

The enclosing g_object_class_install_property call

Implementations

Source

impl ParamSpecAssignment

pub fn is_installed(&self) -> bool

Check if this param_spec assignment is installed (has an install call or is an override)

pub fn get_installed_enum_value(&self) -> Option<&str>

Get the enum value if this assignment is installed For Variable assignments, extracts enum value from install_property call

pub fn property(&self) -> &Property

Get the property information

pub fn param_spec_call(&self) -> Option<&CallExpression>

Get the g_param_spec_* call (None for OverrideProperty)

pub fn statement_location(&self) -> &SourceLocation

pub fn enum_value(&self) -> Option<&str>