pub struct EnumValue {
pub name: String,
pub value: Option<i64>,
pub value_expr: Option<Expression>,
pub location: SourceLocation,
pub name_location: SourceLocation,
pub value_location: Option<SourceLocation>,
pub export_macros: Vec<ExportMacro>,
pub doc: Option<EnumValueDoc>,
}Fields
name: Stringvalue: Option<i64>value_expr: Option<Expression>The expression AST for the value (if present)
location: SourceLocationLocation of this enumerator node
name_location: SourceLocationLocation of just the name
value_location: Option<SourceLocation>Location of the value (if present)
export_macros: Vec<ExportMacro>doc: Option<EnumValueDoc>Implementations
Sourceimpl EnumValue
impl EnumValue
Sourcepub fn is_prop_last(&self) -> bool
pub fn is_prop_last(&self) -> bool
Check if this is a property count sentinel (N_PROPS, PROP_LAST, NUM_PROPERTIES, etc.)
Sourcepub fn is_signal_last(&self) -> bool
pub fn is_signal_last(&self) -> bool
Check if this is a signal count sentinel (N_SIGNALS, LAST_SIGNAL, NUM_SIGNALS, etc.)
Sourcepub fn value_text(&self) -> Option<&str>
pub fn value_text(&self) -> Option<&str>
Extract the value text from source (e.g., for N_PROPS = PROP_ORIENTATION, returns “PROP_ORIENTATION”)