pub struct GObjectType {Show 14 fields
pub type_name: String,
pub type_macro: Option<GType>,
pub function_prefix: String,
pub parent_type: Option<String>,
pub flags: Option<String>,
pub kind: GObjectTypeKind,
pub interfaces: Vec<InterfaceImplementation>,
pub has_private: bool,
pub code_block_statements: Vec<Statement>,
pub export_macros: Vec<String>,
pub doc: Option<TypeDoc>,
pub properties: Vec<ParamSpecAssignment>,
pub signals: Vec<Signal>,
pub location: SourceLocation,
}Fields
type_name: Stringtype_macro: Option<GType>function_prefix: Stringparent_type: Option<String>flags: Option<String>kind: GObjectTypeKindinterfaces: Vec<InterfaceImplementation>has_private: boolcode_block_statements: Vec<Statement>export_macros: Vec<String>doc: Option<TypeDoc>properties: Vec<ParamSpecAssignment>signals: Vec<Signal>location: SourceLocationImplementations
Sourceimpl GObjectType
impl GObjectType
pub fn function_prefix(&self) -> &str
Sourcepub fn init_function_name(&self) -> String
pub fn init_function_name(&self) -> String
Get the expected instance init function name based on the function_prefix
Sourcepub fn class_init_function_name(&self) -> String
pub fn class_init_function_name(&self) -> String
Get the expected class_init function name based on the function_prefix
Sourcepub fn default_init_function_name(&self) -> String
pub fn default_init_function_name(&self) -> String
Get the expected default_init function name for interfaces
Sourcepub fn class_struct_name(&self) -> Option<String>
pub fn class_struct_name(&self) -> Option<String>
Returns the expected name of the class or interface struct for this
type, without the leading underscore. Returns None for final types,
which have no separate class struct.
- Derivable types →
"{TypeName}Class" - Interface types →
"{TypeName}Interface"
Sourcepub fn is_interface(&self) -> bool
pub fn is_interface(&self) -> bool
Check if this is an interface type
Sourcepub fn extract_signals(
&self,
class_init_func: &FunctionDefItem,
source: &[u8],
) -> Vec<Signal>
pub fn extract_signals( &self, class_init_func: &FunctionDefItem, source: &[u8], ) -> Vec<Signal>
Extract signals from a class_init function